@@ -3,9 +3,9 @@ use strict;
 use warnings;
 
 use Data::Dumper;
-use Net::Routing qw($Error);
+use Net::Routing qw($Error :constants);
 
-my $route = Net::Routing->new(target => 'default');
+my $route = Net::Routing->new(target => NR_TARGET_DEFAULT());
 if (! defined($route)) {
    print "ERROR: $Error\n";
    exit(1);
