@@ -3,13 +3,13 @@ use strict;
 use warnings;
 
 use Data::Dumper;
-use Net::Routing;
+use Net::Routing qw($Error :constants);
 
 my $interface = shift or die("Give interface");
 
 my $route = Net::Routing->new(target => $interface);
 if (! defined($route)) {
-   print "ERROR: $Net::Routing::Error\n";
+   print "ERROR: $Error\n";
    exit(1);
 }
 
