@@ -1,11 +1,11 @@
 #
-# $Id: Routing.pm,v 05d886dffb1a 2015/02/20 05:58:44 gomor $
+# $Id: Routing.pm,v 717225574cff 2015/11/12 08:46:57 gomor $
 #
 package Net::Routing;
 use strict;
 use warnings;
 
-our $VERSION = '0.43';
+our $VERSION = '0.44';
 
 use base qw(Class::Gomor::Hash);
 
@@ -92,10 +92,7 @@ sub new {
       @_,
    );
 
-   my @path = qw(/bin /sbin /usr/bin /usr/sbin /usr/local/bin /usr/local/sbin);
-
-   $ENV{LC_ALL} = $self->lc_all;
-   $ENV{PATH} = join(':', $self->path);
+   $self->path([ @{$self->path}, split(':', $ENV{PATH}) ]);
 
    eval("use $_routing_module;");
    if ($@) {
