@@ -1,11 +1,11 @@
 #
-# $Id: Linux.pm,v 05d886dffb1a 2015/02/20 05:58:44 gomor $
+# $Id: Linux.pm,v 717225574cff 2015/11/12 08:46:57 gomor $
 #
 package Net::Routing::Linux;
 use strict;
 use warnings;
 
-our $VERSION = '0.43';
+our $VERSION = '0.44';
 
 use base qw(Net::Routing);
 
@@ -47,16 +47,20 @@ sub get {
    my $family = $self->family;
 
    my $bin = '';
-   for my $path (@{$self->path}) {
-      if (-f "$path/netstat") {
-         $bin = "$path/netstat";
-         last;
+   {
+      local $ENV{LC_ALL} = $self->lc_all;
+
+      for my $path (@{$self->path}) {
+         if (-f "$path/netstat") {
+            $bin = "$path/netstat";
+            last;
+         }
       }
-   }
-   if (! length($bin)) {
-      $Error = "unable to find netstat command from current PATH";
-      return;
-   }
+      if (! length($bin)) {
+         $Error = "unable to find netstat command from current PATH";
+         return;
+      }
+   };
 
    $cmd4 ||= [ $bin, '-rnA', 'inet' ];
    $cmd6 ||= [ $bin, '-rnA', 'inet6' ];
